<div class="peek-ds-main-header"
     *ngIf="isEnabled">
    <div class="container">
        <div class="row peek-ds--mh-buttons-row">
            <div class="btn-group pull-left "
                 role="group">
                <button class="peek-ds-mh-buttons"
                        [routerLink]="['/peek_core_user']">
                    <fa name="user" tooltip="Login / Logout"></fa>
                </button>
                <button class="peek-ds-mh-buttons"
                        [routerLink]="['/peek_core_search']">
                    <fa name="search" tooltip="Search"></fa>
                </button>
                <button
                    class="peek-ds-mh-buttons"
                    *ngFor="let link of leftLinks"
                    [routerLink]="[link.resourcePath]">
                    {{linkTitle(link)}}

                </button>
            </div>
            <div class="btn-group pull-right"
                 role="group">
                <button class="peek-ds-mh-buttons"
                        *ngFor="let link of rightLinks"
                        [routerLink]="[link.resourcePath]">
                    {{linkTitle(link)}}

                </button>
            </div>
        </div>
        <div class="row">
            <div class="peek-ds-mh-title"
                 [class.bg-danger]="!vortexIsOnline">
                {{title}}
                <div class="pull-right">
                    <fa *ngIf="!vortexIsOnline" name="unlink"
                        tooltip="Connection to server is offline"></fa>
                </div>
            </div>
        </div>
    </div>
</div>
