<div class="peek-ds-main-icons peek-home-screen">
    <div class="title h3"
         *ngIf="!appDetails.length">
        No Plugins Installed
    </div>
    <div *ngFor="let app of appDetails">
        <a class="home-screen-icon" [routerLink]="[app.resourcePath]">
            <img class="home-screen-image" [src]="[app.pluginIconPath]">
            <div class="home-screen-title">
                {{app.title}}
            </div>
        </a>
    </div>
</div>
