@import '~@synerty/peek-theme/scss/_variables.web';


.peek-ds-main-icons {
    margin-top: $title_bar_height + $title_bar_height;
    margin-bottom: $title_bar_height;
    padding: $general_padding_1;
    overflow-y: auto;
    min-height: unset !important;
}

