import {Component} from "@angular/core";

@Component({
    selector: "peek-main-root-components",
    templateUrl: "../plugin-root.component.web.html",
    moduleId: module.id
})
export class PluginRootComponent {

    constructor() {

    }


}

